This page is taken from the
[examples/](https://github.com/google-gemini/genai-processors/blob/main/examples/)
directory and refers to the code there.

{% include-markdown "../../../examples/README.md" %}
